@@ -1,4 +1,3 @@
-#include <endian.h>
 #include <algorithm>
 #include <cstring>
 
@@ -20,9 +19,6 @@ ValueType Deserialize(const gsl::span<const gsl::byte> span) {
   ASSERT(span.size() == N * sizeof(uint64_t), "Source span size mismatches BigInt size.");
   std::array<uint64_t, N> value{};
   gsl::copy(span, gsl::byte_span(value));
-  for (uint64_t& x : value) {
-    x = le64toh(x);
-  }
   return ValueType(value);
 }
 
@@ -30,7 +26,7 @@ void Serialize(const ValueType& val, const gsl::span<gsl::byte> span_out) {
   const size_t N = ValueType::LimbCount();
   ASSERT(span_out.size() == N * sizeof(uint64_t), "Span size mismatches BigInt size.");
   for (size_t i = 0; i < N; ++i) {
-    uint64_t limb = htole64(val[i]);
+    uint64_t limb = val[i];
     gsl::copy(gsl::byte_span(limb), span_out.subspan(i * sizeof(uint64_t), sizeof(uint64_t)));
   }
 }
